******************************************************************************
*** "Economic Self-Interest, Information, and Trade Policy Preferences: 
***  Evidence from an Experiment in Tunisia"
***  Review of International Political Economy
***  November 30, 2018
***  APPENDIX TABLES
******************************************************************************

clear all
set more off
set matsize 1000

*Set directory
cd ""

use "data/ripe_tunisia_replication.dta", clear

********************************************************************************
*  Table A2: Summary Statistics
********************************************************************************

estpost sum trans_tradeexp age female educ hiskill monthincome rec_natl1 sociotropic_ordinal re_islam_pca relig_hilo polideo3_1 union_mem informal_ordinal  gvc_25_recode foreign_firms off_shore


esttab . using "output/tableA2.tex", replace /*
*/  label legend  cell((count(fmt(%9.0f)) mean(fmt(%9.2f)) sd(fmt(%9.2f)) min(fmt(%9.2f)) max(fmt(%9.2f)))) nonumber nomtitle


********************************************************************************
* Table A3: Correlation Matrix between Sociocultural Variables
********************************************************************************

local scvars educ hiskill log_income rec_natl1 sociotropic_ordinal re_islam_pca relig_hilo polideo3_1 union_mem informal_ordinal

estpost correlate `scvars', matrix

esttab . using  "output/tableA3.tex",  unstack b(2) p(2) /*
*/ noobs nostar note("Note: P-values in parentheses") title(Correlation Matrix: Sociocultural Variables) nonumber  label legend replace

	
********************************************************************************
* Table A4: Balance Tests
********************************************************************************
	
foreach var in exports imports nontraded public {
		logit bin_`var' age female educ hiskill monthincome rec_natl1 sociotropic_ordinal re_islam_pca relig_hilo polideo3_1 union_mem informal_ordinal ib1.governorate, robust
			est store `var'		
	}
	
	esttab exports imports nontraded public /*
		*/	using "output/tableA4.tex", replace /*
		*/ cells(b(star fmt(%9.3f)) se(par)) stats(N aic bic, fmt(%9.0g %9.3f)) unstack starlevels(* .1 ** .05 *** .01) /*
		*/  label legend varlabels(_cons Constant aic AIC bic BIC) drop(1.governorate) /*
		*/ title(Balance Tests (Governorate)\label{balancetests:gov}) /*
		*/ mtitles("Exports" "Import-Comp." "Non-Traded" "Public") 
	
	
***************************************************************************************************************************
* Tables A5-A16 (Logit/OLS, Fixed Effects/Without Fixed Effects, Full Sample/Only Those Who Passed Manipulation Check)
****************************************************************************************************************************

local dv1 "logit tradeexp_dich"
local dv2 "reg trans_tradeexp"
local dvs "logit ols"

local control1 "age age2 female educ hiskill"
local control2 "age age2 female educ hiskill rec_natl1 sociotropic_ordinal re_islam_pca relig_hilo polideo3_1 union_mem informal_ordinal" 
local control3 "age age2 female educ hiskill log_income"
local control4 "age age2 female educ hiskill log_income rec_natl1 sociotropic_ordinal re_islam_pca relig_hilo polideo3_1 union_mem informal_ordinal" 
local controls "base full baseinc fullinc"


local manipcheck1 ""
local manipcheck2 "if m1pass == 1"
local mcheck "all mchk"

local fe1 ""
local fe2 "i.governorate"
local fes "FE_No FE_Gov"


	forval v = 1/2 {
		local dep: word `v' of `dvs' // Loop over Dependent Variables
	
		forval k = 1/2{
			local mnck: word `k' of `mcheck' // For Full-Sample and Only those passed the manipulation check
	
		forval f = 1/2 {
			local fixed: word `f' of `fes' // Without and with governorate fixed effects 
			
		forval c = 1/4 {
			local covars: word `c' of `controls' // Include baseline and fuller control variables

	
			`dv`v'' treatpool##ib4.bin_all `control`c'' `fe`f'' `manipcheck`k'', vce(cluster governorate) 
		
			est store `dep'_`covars'_`fixed'_`mnck'
		
	
	qui{
			
					
				qui lincom (2.treatpool#1.bin_all - 1.treatpool#1.bin_all) - (2.treatpool#2.bin_all - 1.treatpool#2.bin_all) // export vs. import
					local e_exim_`v'_`c' = round(r(estimate), 0.01)
					local p_exim_`v'_`c' = round(2*ttail(e(N),abs(r(estimate)/r(se))), 0.01)
					local se_exim_`v'_`c' = round(r(se), 0.01)
					estadd scalar exim_e = `e_exim_`v'_`c''
					estadd local exim_se = "(`se_exim_`v'_`c'')"
					estadd scalar exim_p = `p_exim_`v'_`c''
					
				qui lincom (2.treatpool#1.bin_all - 1.treatpool#1.bin_all) - (2.treatpool#3.bin_all - 1.treatpool#3.bin_all) // export vs. nontraded
					local e_exno_`v'_`c' = round(r(estimate), 0.01)
					local p_exno_`v'_`c' = round(2*ttail(e(N),abs(r(estimate)/r(se))), 0.01)
					local se_exno_`v'_`c' = round(r(se), 0.01)
					estadd scalar exno_e = `e_exno_`v'_`c''
					estadd local exno_se = "(`se_exno_`v'_`c'')"
					estadd scalar exno_p = `p_exno_`v'_`c''
					
					
				qui lincom (2.treatpool#1.bin_all - 1.treatpool#1.bin_all) - (2.treatpool#4.bin_all - 1.treatpool#4.bin_all) // export vs. public
					local e_expu_`v'_`c' = round(r(estimate), 0.01)
					local p_expu_`v'_`c' = round(2*ttail(e(N),abs(r(estimate)/r(se))), 0.01)
					local se_expu_`v'_`c' = round(r(se), 0.01)
					estadd scalar expu_e = `e_expu_`v'_`c''
					estadd local expu_se = "(`se_expu_`v'_`c'')"
					estadd scalar expu_p = `p_expu_`v'_`c''
					
				qui lincom (2.treatpool#2.bin_all - 1.treatpool#2.bin_all) - (2.treatpool#3.bin_all - 1.treatpool#3.bin_all) // import vs. nontraded
					local e_imno_`v'_`c' = round(r(estimate), 0.01)
					local p_imno_`v'_`c' = round(2*ttail(e(N),abs(r(estimate)/r(se))), 0.01)
					local  se_imno_`v'_`c' = round(r(se), 0.01)
					estadd scalar imno_e = `e_imno_`v'_`c''
					estadd local imno_se = "(`se_imno_`v'_`c'')"
					estadd scalar imno_p = `p_imno_`v'_`c''
					
				qui lincom (2.treatpool#2.bin_all - 1.treatpool#2.bin_all) - (2.treatpool#4.bin_all - 1.treatpool#4.bin_all) // import vs. public
					local e_impu_`v'_`c' = round(r(estimate), 0.01)
					local p_impu_`v'_`c' = round(2*ttail(e(N),abs(r(estimate)/r(se))), 0.01)
					local se_impu_`v'_`c' = round(r(se), 0.01)
					estadd scalar impu_e = `e_impu_`v'_`c''
					estadd local impu_se = "(`se_impu_`v'_`c'')"
					estadd scalar impu_p = `p_impu_`v'_`c''
					
				qui lincom (2.treatpool#3.bin_all - 1.treatpool#3.bin_all) - (2.treatpool#4.bin_all - 1.treatpool#4.bin_all) // nontraded vs. public
					local e_nopu_`v'_`c' = round(r(estimate), 0.01)
					local p_nopu_`v'_`c' = round(2*ttail(e(N),abs(r(estimate)/r(se))), 0.01)
					local se_nopu_`v'_`c' = round(r(se), 0.01)
					estadd scalar nopu_e = `e_nopu_`v'_`c''
					estadd local nopu_se = "(`se_nopu_`v'_`c'')"
					estadd scalar nopu_p = `p_nopu_`v'_`c''
										
			}
			
			di "`dep'|`fixed'|`covars'|`mnck'|Exporters vs. Importers|`e_ex_`v'_`c''|`p_ex_`v'_`c''|`e_im_`v'_`c''|`p_im_`v'_`c''|`e_exim_`v'_`c''|`se_exim_`v'_`c''|`p_exim_`v'_`c''"
			di "`dep'|`fixed'|`covars'|`mnck'|Exporters vs. Non-traders|`e_ex_`v'_`c''|`p_ex_`v'_`c''|`e_no_`v'_`c''|`p_no_`v'_`c''|`e_exno_`v'_`c''|`se_exno_`v'_`c''|`p_exno_`v'_`c''"
			di "`dep'|`fixed'|`covars'|`mnck'|Exporters vs. Public|`e_ex_`v'_`c''|`p_ex_`v'_`c''|`e_pu_`v'_`c''|`p_pu_`v'_`c''|`e_expu_`v'_`c''|`se_expu_`v'_`c''|`p_expu_`v'_`c''"
			di "`dep'|`fixed'|`covars'|`mnck'|Importers vs. Non-traders|`e_im_`v'_`c''|`p_im_`v'_`c''|`e_no_`v'_`c''|`p_no_`v'_`c''|`e_imno_`v'_`c''|`se_imno_`v'_`c''|`p_imno_`v'_`c''"
			di "`dep'|`fixed'|`covars'|`mnck'|Importers vs. Public|`e_im_`v'_`c''|`p_im_`v'_`c''|`e_pu_`v'_`c''|`p_pu_`v'_`c''|`e_impu_`v'_`c''|`se_impu_`v'_`c''|`p_impu_`v'_`c''"
			di "`dep'|`fixed'|`covars'|`mnck'|Non-traders vs. Public|`e_no_`v'_`c''|`p_no_`v'_`c''|`e_pu_`v'_`c''|`p_pu_`v'_`c''|`e_nopu_`v'_`c''|`se_nopu_`v'_`c''|`p_nopu_`v'_`c''"
			
		
			}
			
		}
	}
}

*** TABLES A5-A14 ****

local comp1 "logit_base_FE_Gov_all logit_full_FE_Gov_all" 
local comp2 "logit_base_FE_No_all logit_full_FE_No_all" 
local comp3 "logit_base_FE_No_mchk logit_full_FE_No_mchk logit_base_FE_Gov_mchk logit_full_FE_Gov_mchk"
local comp4 "ols_base_FE_No_all ols_full_FE_No_all"
local comp5 "ols_base_FE_No_mchk ols_full_FE_No_mchk ols_base_FE_Gov_mchk ols_full_FE_Gov_mchk"

local tit1 "Logit - Main Effects: "
local tit2 "Logit - Main Effects (No Fixed Effects): "
local tit3 "Logit - Main Effects (Manipulation Check): "
local tit4 "Main Effects (No Fixed Effects): "
local tit5 "Main Effects (Manipulation Check): "

local tokeep "2.treatpool* *.bin_all 2.treatpool#*.bin_all  age age2 female educ hiskill rec_natl1 sociotropic_ordinal re_islam_pca relig_hilo polideo3_1 union_mem informal_ordinal"

local j=5

forv u=1/5{


	**** Main Effects
 esttab `comp`u'' using "output/tableA`j'.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par)) stats(N aic bic r2  /*
	*/ , fmt(0 3)) noomitted nobaselevels  /*
	*/ keep(`tokeep')  unstack starlevels(* .1 ** .05 *** .01) label legend varlabels(_cons Constant)  /*
	*/ title(`tit`u'': Support for Trade \label{maineff`j'}) mtitles("Base" "Full") 

	local j = `j'+1
	
	**** Diff and Diff
esttab `comp`u''  using "output/tableA`j'.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par)) stats(exim_e exim_se exim_p exno_e exno_se exno_p expu_e expu_se expu_p imno_e imno_se imno_p impu_e impu_se impu_p nopu_e nopu_se nopu_p /*
	*/ , fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 ))  noomitted nobaselevels /*
	*/ drop(*)  unstack starlevels(* .1 ** .05 *** .01) label legend substitute(exim_e "Exporters vs. Import-Competing" /*
	*/ exim_se "" exno_e "Exporters vs. Non-Traders" exno_se "" expu_e "Exporters vs. Public" expu_se "" imno_e "Import-Competing vs. Non-Traders" imno_se "" /*
	*/ impu_e "Import-Competing vs. Public" impu_se "" nopu_e "Non-Traders vs. Public" nopu_se "") /*
	*/ title(`tit`u'' Difference-in-Differences \label{maineff`j':did}) mtitles("Base" "Full") 
 		
	local j = `j'+1

	
	}
	
	
**** Table A15 (Main Effects with Income)	
esttab ols_baseinc_FE_No_all ols_fullinc_FE_No_all ols_baseinc_FE_Gov_all ols_fullinc_FE_Gov_all using "output/tableA15.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par)) stats(N r2  /*
	*/ , fmt(0 3)) noomitted nobaselevels drop(*.governorate)  unstack starlevels(* .1 ** .05 *** .01) label legend varlabels(_cons Constant) substitute(exim_e "Exporters vs. Import-Competing" /*
	*/ exim_se "" exno_e "Exporters vs. Non-Traders" exno_se "" expu_e "Exporters vs. Public" expu_se "" imno_e "Import-Competing vs. Non-Traders" imno_se "" /*
	*/ impu_e "Import-Competing vs. Public" impu_se "" nopu_e "Non-Traders vs. Public" nopu_se "") /*
	*/ title(Main Effects - Support for Trade (With Income) \label{maineff15})  mtitles("Base" "Full" "Base-FE" "Full-FE")  

**** Table A16 (Main Effects with Income and Diff-in-Diff)
esttab ols_baseinc_FE_No_all ols_fullinc_FE_No_all ols_baseinc_FE_Gov_all ols_fullinc_FE_Gov_all  using "output/tableA16.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par)) stats(exim_e exim_se exim_p exno_e exno_se exno_p expu_e expu_se expu_p imno_e imno_se imno_p impu_e impu_se impu_p nopu_e nopu_se nopu_p /*
	*/ , fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 ))  noomitted nobaselevels /*
	*/ drop(*)  unstack starlevels(* .1 ** .05 *** .01) label legend varlabels(_cons Constant) substitute(exim_e "Exporters vs. Import-Competing" /*
	*/ exim_se "" exno_e "Exporters vs. Non-Traders" exno_se "" expu_e "Exporters vs. Public" expu_se "" imno_e "Import-Competing vs. Non-Traders" imno_se "" /*
	*/ impu_e "Import-Competing vs. Public" impu_se "" nopu_e "Non-Traders vs. Public" nopu_se "") /*
	*/ title(Main Effects - Support for Trade (With Income) (Difference-in-Differences) \label{maineff16})  mtitles("Base" "Full" "Base-FE" "Full-FE")  /*
	*/ addnote("Source: Differences and Differences based on OLS Estimates in Table A15.")

************************************************************************************
* Multiple Imputation Tables A17-A18 
************************************************************************************
	
** (See ripe_mi_analysis.do)	
	
*****************************************************************************************************
* Subgroup Effects: Full Regression Tables (Appendix Tables A19-A28) 
* Reference Categories: Control, Public, and "Low" Subgroup
********************************************************************************************************

local basecov "educ hiskill age age2"
local covariates "educ hiskill female rec_natl1 sociotropic_ordinal re_islam_pca relig_hilo polideo3_1 union_mem informal_ordinal"
local dummies "graduate hiskill female natl1_dich sociotropic_v2 re_islam_pca_dich re_relig_pca_dich polideo3_1_dich union_mem informal_broad"
local labels "grad hiskill female natl socio cislam relig ideo union informal"
local n : word count `covariates'	

forv i = 1/`n' {
	
	local cremove : word `i' of `covariates' // identify ordinal/continous variable to remove
	local sgroup: word `i' of `dummies' // identify binary subgroup 
	local lb: word `i' of `labels' // get label
	
	local covariates: list covariates- cremove // remove ordinal/continuous measure from list of covariates
		di "`covariates'"
	
	* Baseline Models
	* Remove education/skill for the first two subgroups (High Education/Skill)
		
	if (`i' == 1 | `i' == 2) {
		local rem : word `i' of `basecov' // remove education and skill controls for that subgroup
		local basecov: list basecov- rem  
		
		areg trans_tradeexp ib1.treatpool##ib4.bin_all##ib1.`sgroup' `basecov', absorb(governorate) vce(cluster governorate)
		est store `lb'_base
		
		local basecov "educ hiskill age age2" // reassign baseline controls
		}
		
	else {
		areg trans_tradeexp ib1.treatpool##ib4.bin_all##ib1.`sgroup' `basecov', absorb(governorate) vce(cluster governorate)
		est store `lb'_base
		}

	* Full Set of Controls
	
	areg trans_tradeexp ib1.treatpool##ib4.bin_all##ib1.`sgroup' age age2 `covariates', absorb(governorate) vce(cluster governorate)
		est store `lb'_full
	
	local covariates "educ hiskill female rec_natl1 sociotropic_ordinal re_islam_pca relig_hilo polideo3_1 union_mem informal_ordinal" // reassign orginal list of covariates

	
}

*** Tables A19-A28 *** 

local subgoups2 "grad hiskill female union informal natl socio cislam relig ideo"
	local n : word count `subgoups2'	

	local y=19 // start at table A19

forval i = 1/`n' {	

	local u : word `i' of `subgoups2'
	local z : word `i' of `vars'
	
	* Summary Table 6 of Subgroup Effects *
	
	esttab `u'_base `u'_full /*
	*/ using "output/tableA`y'.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par)) stats(N r2,  fmt(0 3)) /*
	*/ noomitted nobaselevels  /*
	*/ label legend varlabels(_cons Constant)  /*
	*/ title(Subgroup Effects: \label{tab:`u'})  mtitles("Base" "Full")
	
	local y = `y'+1
	
}
	
	
*****************************************************************************************************
* Table 29: Off-Shoring (Exporters & Import-Competers)
* OLS, Governorate Fixed Effects, SEs clustered by governorate
********************************************************************************************************
	

areg trans_tradeexp treatpool##ib1.bin_all##i.off_shore age age2 female educ hiskill  if (bin_all ==1 | bin_all==2), absorb(governorate) vce(cluster governorate)		
	est store offshore_base


areg trans_tradeexp treatpool##ib1.bin_all##i.off_shore age age2 female educ hiskill rec_natl1 sociotropic_ordinal re_islam_pca relig_hilo polideo3_1 union_mem informal_ordinal if (bin_all ==1 | bin_all==2), absorb(governorate) vce(cluster governorate)				
	est store offshore_full

	

esttab offshore_base offshore_full  using "output/tableA29.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par))  stats(N r2, fmt(0 3)) /*
	*/ noomitted nobaselevels  /*
	*/unstack starlevels(* .1 ** .05 *** .01) label legend varlabels(_cons Constant) /*
	*/ substitute(r2 "R2" off_shore  "Off-Shore") title(Off-Shore (Exporters \& Import-Competers) \label{offshore})
		

	
*****************************************************************************************************
* Table 30: FDI Firms (Log Transformed) (Export, Import-Competers)  
* OLS, No Fixed Effects, SEs clustered by governorate
********************************************************************************************************
		
reg trans_tradeexp treatpool##ib1.bin_all##c.log_fdifirms  age age2 female educ hiskill  if (bin_all ==1 | bin_all==2),  vce(cluster governorate)		
	est store fdi_base


reg trans_tradeexp treatpool##ib1.bin_all##c.log_fdifirms  age age2 female educ hiskill rec_natl1 sociotropic_ordinal re_islam_pca relig_hilo polideo3_1 union_mem informal_ordinal if (bin_all ==1 | bin_all==2), vce(cluster governorate)		
	est store fdi_full
		
	
esttab fdi_base fdi_full  using "output/tableA30.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par))  stats(N r2, fmt(0 3)) /*
	*/ noomitted nobaselevels  /*
	*/unstack starlevels(* .1 ** .05 *** .01) label legend varlabels(_cons Constant) /*
	*/ substitute(r2 "R2" log_fdifirms  "FDI") title(FDI Firms (Exporters \& Import-Competers) \label{fdi})
		
	
	
