******************************************************************************
*** "Economic Self-Interest, Information, and Trade Policy Preferences: 
***  Evidence from an Experiment in Tunisia"
***  Review of International Political Economy
***  November 30, 2018
******************************************************************************
clear all
set more off
set matsize 1000

*Set Directory
cd ""

use "data/ripe_tunisia_replication.dta", clear


log using "log/RIPE_replication", replace


*******************************************************************************
* Table 1 (Pre-Experiment Questions: Support for Trade Liberalization)
*******************************************************************************

** Table 1 Pre-Experimental Questions by Sector 
foreach v of varlist trans_gind2_* {
	ta  bin_all `v', row
	ta hiskill  `v', row
}


********************************************************************************
* Figure 1: Support for Trade by Sector & Informational Cues 
* (Means and Confidence Intervals)
********************************************************************************

table bin_all info, c(mean trans_tradeexp n trans_tradeexp)

eststo mean_exports: mean trans_tradeexp if bin_all ==1, over(bin_all info)
eststo mean_imports: mean trans_tradeexp if bin_all ==2, over(bin_all info)
eststo mean_nontraded: mean trans_tradeexp if bin_all ==3, over(bin_all info)
eststo mean_public: mean trans_tradeexp if bin_all ==4, over(bin_all info)


*** Figure 1 **
coefplot mean_exports mean_imports mean_nontraded mean_public, ///
vertical  mlabel format(%9.2g) ///
grid(between glcolor(black) glpattern(dash)) ///
coeflabels(_subpop_1 = "No Info" _subpop_2 = "Sector Info" _subpop_3 = "Effects Info") ///
legend( order(2 "Exporters" 4 "Import-Competing" 6 "Non-Traders" 8 "Public")) ///
title("Support for Trade Liberalization") subtitle("By Sector") ytitle("No limits on foreign trade (%)") 
graph export "output/Figure1.pdf", replace 


********************************************************************************
* Tables 2 & 3 (Main Effects & Diff-in-Diffs)
* OLS Models, Governorate Fixed Effects, Robust SEs Clustered by Governorate
********************************************************************************

local control1 "age age2 female educ hiskill"
local control2 "age age2 female educ hiskill rec_natl1 sociotropic_ordinal re_islam_pca relig_hilo polideo3_1 union_mem informal_ordinal" 
local controls "base full"

forval c = 1/2 {

	areg trans_tradeexp treatpool##ib4.bin_all `control`c'', absorb(governorate) vce(cluster governorate) 
			est store `:word `c' of `controls''_FE_Gov_1_all
			
			
	qui{
				* Difference-in-Difference Estimations
				qui lincom (2.treatpool#1.bin_all - 1.treatpool#1.bin_all) - (2.treatpool#2.bin_all - 1.treatpool#2.bin_all) // export vs. import
					local e_exim_`v'_`c' = round(r(estimate), 0.01)
					local p_exim_`v'_`c' = round(2*ttail(r(df),abs(r(estimate)/r(se))), 0.01)
					local se_exim_`v'_`c' = round(r(se), 0.01)
					estadd scalar exim_e = `e_exim_`v'_`c''
					estadd local exim_se = "(`se_exim_`v'_`c'')"
					estadd scalar exim_p = `p_exim_`v'_`c''
					
				qui lincom (2.treatpool#1.bin_all - 1.treatpool#1.bin_all) - (2.treatpool#3.bin_all - 1.treatpool#3.bin_all) // export vs. nontraded
					local e_exno_`v'_`c' = round(r(estimate), 0.01)
					local p_exno_`v'_`c' = round(2*ttail(r(df),abs(r(estimate)/r(se))), 0.01)
					local se_exno_`v'_`c' = round(r(se), 0.01)
					estadd scalar exno_e = `e_exno_`v'_`c''
					estadd local exno_se = "(`se_exno_`v'_`c'')"
					estadd scalar exno_p = `p_exno_`v'_`c''
				
				qui lincom (2.treatpool#1.bin_all - 1.treatpool#1.bin_all) - (2.treatpool#4.bin_all - 1.treatpool#4.bin_all) // export vs. public
					local e_expu_`v'_`c' = round(r(estimate), 0.01)
					local p_expu_`v'_`c' = round(2*ttail(r(df),abs(r(estimate)/r(se))), 0.01)
					local se_expu_`v'_`c' = round(r(se), 0.01)
					estadd scalar expu_e = `e_expu_`v'_`c''
					estadd local expu_se = "(`se_expu_`v'_`c'')"
					estadd scalar expu_p = `p_expu_`v'_`c''
					
				qui lincom (2.treatpool#2.bin_all - 1.treatpool#2.bin_all) - (2.treatpool#3.bin_all - 1.treatpool#3.bin_all) // import vs. nontraded
					local e_imno_`v'_`c' = round(r(estimate), 0.01)
					local p_imno_`v'_`c' = round(2*ttail(r(df),abs(r(estimate)/r(se))), 0.01)
					local  se_imno_`v'_`c' = round(r(se), 0.01)
					estadd scalar imno_e = `e_imno_`v'_`c''
					estadd local imno_se = "(`se_imno_`v'_`c'')"
					estadd scalar imno_p = `p_imno_`v'_`c''
					
				qui lincom (2.treatpool#2.bin_all - 1.treatpool#2.bin_all) - (2.treatpool#4.bin_all - 1.treatpool#4.bin_all) // import vs. public
					local e_impu_`v'_`c' = round(r(estimate), 0.01)
					local p_impu_`v'_`c' = round(2*ttail(r(df),abs(r(estimate)/r(se))), 0.01)
					local se_impu_`v'_`c' = round(r(se), 0.01)
					estadd scalar impu_e = `e_impu_`v'_`c''
					estadd local impu_se = "(`se_impu_`v'_`c'')"
					estadd scalar impu_p = `p_impu_`v'_`c''
					
				qui lincom (2.treatpool#3.bin_all - 1.treatpool#3.bin_all) - (2.treatpool#4.bin_all - 1.treatpool#4.bin_all) // nontraded vs. public
					local e_nopu_`v'_`c' = round(r(estimate), 0.01)
					local p_nopu_`v'_`c' = round(2*ttail(r(df),abs(r(estimate)/r(se))), 0.01)
					local se_nopu_`v'_`c' = round(r(se), 0.01)
					estadd scalar nopu_e = `e_nopu_`v'_`c''
					estadd local nopu_se = "(`se_nopu_`v'_`c'')"
					estadd scalar nopu_p = `p_nopu_`v'_`c''

					}
			
			di "`:word `c' of `controls''|Exporters vs. Importers|`e_ex_`v'_`c''|`p_ex_`v'_`c''|`e_im_`v'_`c''|`p_im_`v'_`c''|`e_exim_`v'_`c''|`se_exim_`v'_`c''|`p_exim_`v'_`c''"
			di "`:word `c' of `controls''|Exporters vs. Non-traders|`e_ex_`v'_`c''|`p_ex_`v'_`c''|`e_no_`v'_`c''|`p_no_`v'_`c''|`e_exno_`v'_`c''|`se_exno_`v'_`c''|`p_exno_`v'_`c''"
			di "`:word `c' of `controls''|Exporters vs. Public|`e_ex_`v'_`c''|`p_ex_`v'_`c''|`e_pu_`v'_`c''|`p_pu_`v'_`c''|`e_expu_`v'_`c''|`se_expu_`v'_`c''|`p_expu_`v'_`c''"
			di "`:word `c' of `controls''|Importers vs. Non-traders|`e_im_`v'_`c''|`p_im_`v'_`c''|`e_no_`v'_`c''|`p_no_`v'_`c''|`e_imno_`v'_`c''|`se_imno_`v'_`c''|`p_imno_`v'_`c''"
			di "`:word `c' of `controls''|Importers vs. Public|`e_im_`v'_`c''|`p_im_`v'_`c''|`e_pu_`v'_`c''|`p_pu_`v'_`c''|`e_impu_`v'_`c''|`se_impu_`v'_`c''|`p_impu_`v'_`c''"
			di "`:word `c' of `controls''|Non-traders vs. Public|`e_no_`v'_`c''|`p_no_`v'_`c''|`e_pu_`v'_`c''|`p_pu_`v'_`c''|`e_nopu_`v'_`c''|`se_nopu_`v'_`c''|`p_nopu_`v'_`c''"
				
	}
	
	
**** Table 2 (Main Effects, OLS, Governorate Fixed Effects)
 esttab base_FE_Gov_1_all full_FE_Gov_1_all  using "output/table2.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par)) stats(N r2  /*
	*/ , fmt(0 3)) /*
	*/ noomitted nobaselevels  unstack starlevels(* .1 ** .05 *** .01) label legend varlabels(_cons Constant) /*
	*/ title(Main Effects - Support for Trade \label{maineff}) nomtitles /*
	*/ addnote("OLS estimates with robust standard errors clustered by governorate. Control and Public Sector are reference categories. Governorate Fixed effects not shown.")

**** Table 3 (Difference-in-Differences, OLS, Governorate Fixed Effects)
esttab base_FE_Gov_1_all full_FE_Gov_1_all using "output/table3.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par)) stats(exim_e exim_se exim_p exno_e exno_se exno_p expu_e expu_se expu_p imno_e imno_se imno_p impu_e impu_se impu_p nopu_e nopu_se nopu_p /*
	*/ , fmt(3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 )) /*
	*/ drop(*)  unstack starlevels(* .1 ** .05 *** .01) label legend substitute(exim_e "Exporters vs. Import-Competing" /*
	*/ exim_se "" exno_e "Exporters vs. Non-Traders" exno_se "" expu_e "Exporters vs. Public" expu_se "" imno_e "Import-Competing vs. Non-Traders" imno_se "" /*
	*/ impu_e "Import-Competing vs. Public" impu_se "" nopu_e "Non-Traders vs. Public" nopu_se "") /*
	*/ title(Difference-in-Differences: Support for Trade \label{maineff:did}) nomtitles /*
	*/ addnote("Difference-in-Differences (DID) between sectors, calculated from OLS estimates reported in Table 2. Control and Public Sector are reference categories.")
 		
		
	
**************************************************************************************************
* Table 4 GVC Participation
* Subset to only exporters and importers
**************************************************************************************************

	
areg trans_tradeexp treatpool##ib1.bin_all##i.gvc_25_recode age age2 female educ hiskill if (bin_all ==1 | bin_all==2), absorb(governorate) vce(cluster governorate)		
	est store GVC_m1_base

areg trans_tradeexp treatpool##ib1.bin_all##i.gvc_25_recode age age2 female educ hiskill rec_natl1 sociotropic_ordinal re_islam_pca /*
*/ relig_hilo polideo3_1 union_mem informal_ordinal if (bin_all ==1 | bin_all==2), absorb(governorate) vce(cluster governorate)				
	est store GVC_m2_full
	

esttab GVC_m1_base GVC_m2_full  using "output/table4.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par))  stats(N r2, fmt(0 3)) /*
	*/  noomitted nobaselevels /*
	*/ unstack starlevels(* .1 ** .05 *** .01) label legend varlabels(_cons Constant) /*
	*/ substitute(r2 "R2" gvc_25_recode "No GVC") /*
	*/ title(GVC Participation Support for Trade \label{gvcs}) nomtitles 
	
	
*****************************************************************************************************
* Subgroup Effects Summary Tables: Table 5 (Economic) & Table 6 (Sociocultural)
* Reference Categories: Control, Public, and "Low" Subgroup
* Full Regression Tables (Appendix Tables A19-A28) 
********************************************************************************************************

local basecov "educ hiskill age age2"
local covariates "educ hiskill female rec_natl1 sociotropic_ordinal re_islam_pca relig_hilo polideo3_1 union_mem informal_ordinal"
local dummies "graduate hiskill female natl1_dich sociotropic_v2 re_islam_pca_dich re_relig_pca_dich polideo3_1_dich union_mem informal_broad"
local labels "grad hiskill female natl socio cislam relig ideo union informal"
local n : word count `covariates'	

forv i = 1/`n' {
	
	local cremove : word `i' of `covariates' // identify ordinal/continous variable to remove
	local sgroup: word `i' of `dummies' // identify binary subgroup 
	local lb: word `i' of `labels' // get label
	
	local covariates: list covariates- cremove // remove ordinal/continuous measure from list of covariates
		di "`covariates'"
	
	* Baseline Models
	* Remove education/skill for the first two subgroups (High Education/Skill)
		
	if (`i' == 1 | `i' == 2) {
		local rem : word `i' of `basecov' // remove education and skill controls for that subgroup
		local basecov: list basecov- rem  
		
		areg trans_tradeexp ib1.treatpool##ib4.bin_all##ib1.`sgroup' `basecov', absorb(governorate) vce(cluster governorate)
		est store `lb'_base
		
		local basecov "educ hiskill age age2" // reassign baseline controls
		}
		
	else {
		areg trans_tradeexp ib1.treatpool##ib4.bin_all##ib1.`sgroup' `basecov', absorb(governorate) vce(cluster governorate)
		est store `lb'_base
		}

	* Full Set of Controls
	
	areg trans_tradeexp ib1.treatpool##ib4.bin_all##ib1.`sgroup' age age2 `covariates', absorb(governorate) vce(cluster governorate)
		est store `lb'_full
	
	local covariates "educ hiskill female rec_natl1 sociotropic_ordinal re_islam_pca relig_hilo polideo3_1 union_mem informal_ordinal" // reassign orginal list of covariates

	
}

*** Table 5 (Economic Subgroup Summary Table) & Appendix Tables 19-29 *** 

* Table 5 - Lines 1-3 (Education)
	esttab grad_base grad_full /*
	*/ using "output/table5a.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par)) stats(N r2,  fmt(0 3)) /*
	*/ noomitted nobaselevels /*
	*/ keep(2.treatpool#*.bin_all#2.graduate) /*
	*/ label legend varlabels(_cons Constant)  /*
	*/ title(Subgroup Effects: Low vs. High Education table\label{tab:education})  mtitles("Base" "Full")
	

* Table 5 - Lines 4-6 (Skill)
	esttab hiskill_base hiskill_full /*
	*/ using "output/table5b.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par)) stats(N r2,  fmt(0 3)) /*
	*/ noomitted nobaselevels /*
	*/ keep(2.treatpool#*.bin_all#2.hiskill) /*
	*/ label legend varlabels(_cons Constant)  /*
	*/ title(Subgroup Effects: Low vs. High Skill table\label{tab:hiskill})  mtitles("Base" "Full")
	

*** Table 6 (Sociocultural Subgroup Effects Summary Table) *** 

local sociogroups "female union informal natl socio cislam relig ideo"
	local n : word count `sociogroups'	
local vars "female union_mem informal_broad natl1_dich sociotropic_v2 re_islam_pca_dich re_relig_pca_dich polideo3_1_dich"


forval i = 1/`n' {	

	local u : word `i' of `sociogroups'
	local z : word `i' of `vars'
	
	* Summary Table 6 of Subgroup Effects *
	
	esttab `u'_base `u'_full /*
	*/ using "output/table6-`u'.tex", replace /*
	*/ cells(b(star fmt(%9.3f)) se(par)) stats(N r2,  fmt(0 3)) /*
	*/ noomitted nobaselevels /*
	*/ keep(2.treatpool#*.bin_all#2.`z') /*
	*/ label legend varlabels(_cons Constant)  /*
	*/ title(Subgroup Effects: Sociocultural Variables \label{tab:`u'})  mtitles("Base" "Full")
	
}
	
log close

translate "log/RIPE_replication.smcl" "log/RIPE_replication.pdf", replace
